# GPTCovLet
This takes in a job posting and some personal details then uses chatGPT to produce a human-like cover letter.

![](https://img.shields.io/badge/license-MIT-blue)

# Overview
It's unreasonable for companies to mandate a cover letter when you are applying to many different ones. So this is to help streamline that process.
